#
# spec file for package libshout
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libshout
Version:        2.4.6
Release:        2.2
Summary:        Library for communcating with Icecast servers
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://icecast.org/
#Git-Clone:     https://gitlab.xiph.org/xiph/icecast-libshout/
Source:         https://downloads.xiph.org/releases/libshout/%name-%version.tar.gz
Source1:        baselibs.conf
Patch1:         0001-icy-include-stdlib-h-and-stdio-h.patch
Patch2:         0002-legacy-include-stdlib-h.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)

%description
libshout is a library for communicating with and sending data to an
Icecast server. It handles the socket connection, the timing of the
data, and prevents bad data from getting to the Icecast server.

%package -n libshout3
Summary:        Library for communicating with Icecast servers
Group:          System/Libraries

%description -n libshout3
libshout is a library for communicating with and sending data to an
Icecast server. It handles the socket connection, the timing of the
data, and prevents bad data from getting to the Icecast server.

%package devel
Summary:        Development files for libshout, an Icecast communication library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libshout3 = %version

%description devel
This package contains the include files needed to develop
applications that want to use libshout.

%prep
%autosetup -p1

%build
autoreconf --force --install
%configure --disable-static
%make_build

%install
%make_install
# remove unneeded files
find %buildroot -type f -name "*.la" -delete -print
rm -r "%buildroot/%_datadir/doc/%name"
# remove (possibly) unused ckport definitions (use libabigail instead?)
rm -R "%buildroot/%_libdir/ckport"

%post   -n libshout3 -p /sbin/ldconfig
%postun -n libshout3 -p /sbin/ldconfig

%files -n libshout3
%_libdir/*.so.3*

%files devel
%doc README doc/*.xml examples/*.c
%license COPYING
%_bindir/shout
%_libdir/*.so
%_includedir/shout
%_mandir/man1/shout.1%{?ext_man}
%_datadir/aclocal/*.m4
%_libdir/pkgconfig/*.pc

%changelog
* Wed Mar  6 2024 Takashi Iwai <tiwai@suse.com>
- Fix build errors with gcc14 (bsc#1220975):
  0001-icy-include-stdlib-h-and-stdio-h.patch
  0002-legacy-include-stdlib-h.patch
* Thu May  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.4.6
  * Fixed pkg-config file
  * Made vorbis an optional codec
  * Do not pass to small headers to libspeex
    (see also the same mirror-patch in Icecast)
  * Updated documentation, mostly in regard of making it clearer
    which functions are now obsoleted
  * General code cleanup
  * Added compiler warnings about obsoleted functions and
    ignored return values
  * Replaced old shout_set_metadata() with new shout_set_metadata_utf8()
  * Added support for plain text streaming
  * Fixed shout_set_metadata*() sometimes returning SHOUTERR_RETRY
  * Workaround old clients by emulating SHOUTERR_RETRY with
    SHOUTERR_BUSY
  * Remove our re-implementation of X509_check_host()
  * Allow to disable building tools
- Spec cleanup
* Sun Jan 17 2021 Dirk Müller <dmueller@suse.com>
- update to 2.4.5:
  * Improved shout.h for reading, and understanding.
  * Marked dumpfile support as obsolete (as SHOUT_PROTOCOL_XAUDIOCAST already is).
  * Added Support for setting the content language.
  * Avoid the use of obsolete functions (#2317).
  * Several small fixes for non-blocking mode (#2321, #2315).
  * Corrected detection of libogg (mostly for windows targets).
  * Now accept TLS mode "auto" when build without TLS support.
  * Added new tool shout(1).
* Fri Oct  9 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.4.4:
  * Fixed handling of blocking/non-blocking mode
  * Fixed ICY port increment
  * Fixed reusing of handles
  * Fixed error handling of Ogg sync layer
  * Fixed passing of errors between connection and instance layer
    (Without this fix, dead connections were not correctly
    detected)
  * Fixed and improved build scripts
* Sun Sep  1 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4.3
  * Fixed building with OpenSSL 1.1.0.
  * Added support for PUT.
  * Added support for WebM and Matroska with full timing.
* Wed Feb  7 2018 jengelh@inai.de
- Fix typographic tidbits in description. Compact filelist.
- Drop old Obsoletes.
* Wed Dec 23 2015 jengelh@inai.de
- Update to new upstream release 2.4.1
  * Support for TLS (HTTPS) (RFC2817 and RFC2818),
  mode can be autodetected
  * Support for audio-only WebM
  * Improved protocol level metadata support.
  (Some API calls got replaced and marked as obsolete)
  * Improved HTTP protocol: Set Host:-header (vhosting support);
  and check for server capabilities
  * Added basic support for the RoarAudio protocol
- Drop libshout-2.2.2-pkgconfig-bloat.patch (no longer needed)
- Use smp_mflags for building; drop unnecessary %%clean;
  abolish %%__tool indirections.
* Tue Jan 22 2013 jw@suse.com
- update to 2.3.1
  * removed upstreamed libshout-2.2.2-missing-lib.patch
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Removed self-obsoletes (fix for RPMLINT warning)
* Wed Dec 26 2007 crrodriguez@suse.de
- previous change introduced a undefined reference to `speex_packet_to_header'
  library wants to use speex but does not link to it correctly
  (libshout-2.2.2-missing-lib.patch)
* Sun Dec 16 2007 crrodriguez@suse.de
- support speex
- fix library packaging policy change
- cleanup unneeded dependencies and pkgconfig script
* Mon Apr 16 2007 tiwai@suse.de
- follow library packaging policy
  * move docs to devel package
  * remove static library
- added missing ldconfig to post and postun.
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 2.2.2:
  * Handle Oggs that don't begin with zero granulepos
  * Theora memory leak fix
  * Non-blocking shout_open was failing unnecessarily in the
    connect_pending state.
  * Cast some size_ts to ints for display purposes.
  * Fix error handling while opening a connection, so that shout_open
    can be retried.
  * pkgconfig fix for header installation
  * Fix a memory leak in HTTP authentication
* Thu Apr 27 2006 mrueckert@suse.de
- added libtheora-devel libvorbis-devel to the requires of the
  devel package.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 tiwai@suse.de
- updated to version 2.2.
* Tue Jun 14 2005 tiwai@suse.de
- initial version: 2.1
